#!/usr/bin/sh
# 	Copyright (c) 2003-2008 The SCO Group, Inc. All Rights Reserved. 

#ident	"@(#)opensrc:src/cups/cups.sh /main/uw714mp/9"

#
# This directory contains:
#
# dist/*	Source files from cups-1.3.3 distribution.
# patches/*	Patches to be applied.
# cups.sh	Build script (this file).
# cups.depend	Depend file for top-level build script.
#
# cups.pam.*	Pam configuration files.
# chprnsys.sh	Script to switch print system.
# chprnsys.8	Man page for chprnsys.
# printerGUI	Scoadmin piece.
# printjobGUI	Scoadmin piece.
#

set -x
set -e

cd dist

# Apply patches.
for patch in 1.3.3-port
do
	[ -f ../patches/${patch}.applied ] || {
		$TOOLS/usr/gnu/bin/patch -b -p1 -i ../patches/${patch}.patch
		/bin/date > ../patches/${patch}.applied
	}
done

# Override test for "ar" and "strip" by defining absolute pathnames.
AR=$TOOLS/usr/ccs/bin/$AR; export AR
STRIP=$TOOLS/usr/ccs/bin/$STRIP; export STRIP

# Configure
# true \
./configure \
	--host=i386-unknown-sysv5UnixWare7.1.4 \
	--build=i386-unknown-sysv5UnixWare7.1.4 \
	--prefix=/usr \
	--bindir=/usr/lib/cups/bin \
	--sbindir=/usr/lib/cups/sbin \
	--sysconfdir=/etc \
	--localstatedir=/var \
	--mandir=/usr/lib/cups/man \
	--with-docdir=/usr/share/cups/doc \
	--enable-static \
	--disable-gssapi \
	--disable-cdsassl \
	--disable-gnutls \
	--enable-openssl

# Make sure support for all add-on libraries was added.
# TODO Add check for -lslp, -ldap and -lpam.
count=0
for i in `./cups-config --image --libs`
do
	case $i in
	-lcupsimage | -lcups | \
	-ljpeg | -lpng | -ltiff | \
	-lssl | -lcrypto | \
	-lz)
		count=`expr $count + 1` ;;
	esac
done
set +e
if [ $count -ne 8 ]
then
	echo "ERROR: one or more required libraries not found." >&2
	exit 1
fi
set -e

# Make.
$MAKE

# Install header and libraries in cross environment.

# libcups:
cd cups
$MAKE DSTROOT=$TOOLS install
cd ..

# libcupsimage:
cd filter
$MAKE DSTROOT=$TOOLS installhdrs installstatic

# There is no tag for installing libcupsimage.so.2.
$INSTALL -m 755 libcupsimage.so.2 $TOOLS/usr/lib
/bin/rm -f $TOOLS/usr/lib/libcupsimage.so
/bin/ln -s $TOOLS/usr/lib/libcupsimage.so.2 $TOOLS/usr/lib/libcupsimage.so
cd ..

# Now install everything in $ROOT/$MACH.
$MAKE DSTROOT=$ROOT/$MACH install

# Install chprnsys script and its man page.
cd ..
$INSTALL -d $ROOT/$MACH/usr/sbin
$INSTALL -d $ROOT/$MACH/usr/man/man.8
$INSTALL -m 500 chprnsys.sh $ROOT/$MACH/usr/sbin/chprnsys
$INSTALL -m 444 chprnsys.8 $ROOT/$MACH/usr/man/man.8

# Install scoadmin pieces.
$INSTALL -d $ROOT/$MACH/usr/lib/cups/scoadmin
$INSTALL -m 555 printerGUI $ROOT/$MACH/usr/lib/cups/scoadmin
$INSTALL -m 555 printjobGUI $ROOT/$MACH/usr/lib/cups/scoadmin

# Install PAM configuration file.
$INSTALL -d $ROOT/$MACH/etc/pam.d
$INSTALL -m 644 cups.pam $ROOT/$MACH/etc/pam.d/cups
$INSTALL -m 644 cups.pam.build $ROOT/$MACH/etc/pam.d/cups.build

# Rename man page directories
# We could do a simple mv but it does not work for repeated runs of this
# script.
_mv()
{
	# Move all files from directory $1 to $2.
	[ ! -d $1 ] && return
	[ ! -d $2 ] && mkdir -p $2
	ls $1 | xargs -i mv -f $1/{} $2/{}
}

cd $ROOT/$MACH/usr/lib/cups/man/
_mv man1 man.1
_mv man5 man.5
_mv man7 man.7
_mv man8 man.8

exit 0
